@@ -2,9 +2,4 @@
 # that the filehandle object is a Fh
 package Fh;
 
-use strict;
-use warnings;
-
-$Fh::VERSION = '4.35_01';
-
 1;
